@@ -110,6 +110,8 @@ if (reply)
       const char *retval = (g_getenv ("AT_SPI_CLIENT") ?
                             "":
                             spi_global_app_data->app_bus_addr);
+      if (!retval)
+        retval = "";
       dbus_message_append_args(reply, DBUS_TYPE_STRING, &retval, DBUS_TYPE_INVALID);
     }
 
