@@ -25,8 +25,6 @@
 #define _GNU_SOURCE
 #include "config.h"
 
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -36,9 +34,8 @@
 #include <atk/atk.h>
 
 #include <droute/droute.h>
-#include <gmodule.h>
-#include <glib/gi18n.h>
 #include <atspi/atspi.h>
+#include <atk-bridge.h>
 
 #include "bridge.h"
 #include "event.h"
@@ -59,57 +56,7 @@ signal_filter (DBusConnection *bus, DBusMessage *message, void *user_data);
 
 SpiBridge *spi_global_app_data = NULL;
 
-/*static Display *bridge_display = NULL;*/
-
-/*---------------------------------------------------------------------------*/
-
-/*
- * Returns a 'canonicalized' value for DISPLAY,
- * with the screen number stripped off if present.
- *
- */
-static const gchar *
-spi_display_name (void)
-{
-  static const char *canonical_display_name = NULL;
-  if (!canonical_display_name)
-    {
-      const gchar *display_env = g_getenv ("AT_SPI_DISPLAY");
-      if (!display_env)
-        {
-          display_env = g_getenv ("DISPLAY");
-          if (!display_env || !display_env[0])
-            canonical_display_name = ":0";
-          else
-            {
-              gchar *display_p, *screen_p;
-              canonical_display_name = g_strdup (display_env);
-              display_p = strrchr (canonical_display_name, ':');
-              screen_p = strrchr (canonical_display_name, '.');
-              if (screen_p && display_p && (screen_p > display_p))
-                {
-                  *screen_p = '\0';
-                }
-            }
-        }
-      else
-        {
-          canonical_display_name = display_env;
-        }
-    }
-  return canonical_display_name;
-}
-
-/*---------------------------------------------------------------------------*/
-
-static void
-set_reply (DBusPendingCall *pending, void *user_data)
-{
-    void **replyptr = (void **)user_data;
-
-    *replyptr = dbus_pending_call_steal_reply (pending);
-  dbus_pending_call_unref (pending);
-}
+static gboolean inited = FALSE;
 
 /*---------------------------------------------------------------------------*/
 
@@ -118,7 +65,6 @@ add_event (const char *bus_name, const char *event)
 {
   event_data *evdata;
   gchar **data;
-  GList *new_list;
 
   spi_atk_add_client (bus_name);
   evdata = (event_data *) g_malloc (sizeof (*evdata));
@@ -132,9 +78,7 @@ add_event (const char *bus_name, const char *event)
     }
   evdata->bus_name = g_strdup (bus_name);
   evdata->data = data;
-  new_list = g_list_append (spi_global_app_data->events, evdata);
-  if (new_list)
-    spi_global_app_data->events = new_list;
+  spi_global_app_data->events = g_list_append (spi_global_app_data->events, evdata);
 }
 
 static GSList *clients = NULL;
@@ -285,7 +229,6 @@ register_reply (DBusPendingCall *pending, void *user_data)
 {
   DBusMessage *reply;
   SpiBridge *app = user_data;
-  DBusMessage *message;
 
   reply = dbus_pending_call_steal_reply (pending);
   dbus_pending_call_unref (pending);
@@ -323,11 +266,10 @@ register_reply (DBusPendingCall *pending, void *user_data)
 static gboolean
 register_application (SpiBridge * app)
 {
-  DBusMessage *message, *reply;
+  DBusMessage *message;
   DBusMessageIter iter;
   DBusError error;
   DBusPendingCall *pending;
-  const int max_addr_length = 128; /* should be long enough */
 
   dbus_error_init (&error);
 
@@ -355,16 +297,16 @@ register_application (SpiBridge * app)
   if (message)
     dbus_message_unref (message);
 
-  /* could this be better, we accept some amount of race in getting the temp name*/
-  /* make sure the directory exists */
-  mkdir ("/tmp/at-spi2/", S_IRWXU|S_IRWXG|S_IRWXO|S_ISVTX);
-  chmod ("/tmp/at-spi2/", S_IRWXU|S_IRWXG|S_IRWXO|S_ISVTX);
-  app->app_bus_addr = g_malloc(max_addr_length * sizeof(char));
 #ifndef DISABLE_P2P
-  sprintf (app->app_bus_addr, "unix:path=/tmp/at-spi2/socket-%d-%d", getpid(),
-           rand());
-#else
-  app->app_bus_addr [0] = '\0';
+  app->app_tmp_dir = g_build_filename (g_get_user_runtime_dir (),
+                                       "at-spi2-XXXXXX", NULL);
+  if (!g_mkdtemp (app->app_tmp_dir))
+  {
+    g_free (app->app_tmp_dir);
+    app->app_tmp_dir = NULL;
+    return FALSE;
+  }
+  app->app_bus_addr = g_strdup_printf ("unix:path=%s/socket", app->app_tmp_dir);
 #endif
 
   return TRUE;
@@ -395,6 +337,20 @@ deregister_application (SpiBridge * app)
   dbus_connection_send (app->bus, message, NULL);
   if (message)
     dbus_message_unref (message);
+
+  if (app->app_bus_addr)
+  {
+    unlink (app->app_bus_addr);
+    g_free (app->app_bus_addr);
+    app->app_bus_addr = NULL;
+  }
+
+  if (app->app_tmp_dir)
+  {
+    rmdir (app->app_tmp_dir);
+    g_free (app->app_tmp_dir);
+    app->app_tmp_dir = NULL;
+  }
 }
 
 /*---------------------------------------------------------------------------*/
@@ -521,8 +477,8 @@ install_plug_hooks ()
   socket_class->embed = socket_embed_hook;
 }
 
-static uint
-get_ancestral_uid (uint pid)
+static guint
+get_ancestral_uid (guint pid)
 {
   FILE *fp;
   char buf [80];
@@ -566,8 +522,6 @@ user_check (DBusConnection *bus, unsigned long uid, void *data)
 static void
 new_connection_cb (DBusServer *server, DBusConnection *con, void *data)
 {
-  GList *new_list;
-
   dbus_connection_set_unix_user_function (con, user_check, NULL, NULL);
   dbus_connection_ref(con);
   atspi_dbus_connection_setup_with_g_main(con, NULL);
@@ -584,6 +538,9 @@ setup_bus (void)
   DBusServer *server;
   DBusError err;
 
+  if (!spi_global_app_data->app_bus_addr)
+    return -1;
+
   dbus_error_init(&err);
   server = dbus_server_listen(spi_global_app_data->app_bus_addr, &err);
   if (server == NULL)
@@ -645,7 +602,6 @@ handle_event_listener_registered (DBusConnection *bus, DBusMessage *message,
 static void
 remove_events (const char *bus_name, const char *event)
 {
-  event_data *evdata;
   gchar **remove_data;
   GList *list;
 
@@ -681,7 +637,6 @@ static void
 handle_event_listener_deregistered (DBusConnection *bus, DBusMessage *message,
                                     void *user_data)
 {
-  const char *orig_name;
   gchar *name;
   char *sender;
 
@@ -761,6 +716,27 @@ signal_filter (DBusConnection *bus, DBusMessage *message, void *user_data)
   return result;
 }
 
+/*
+ * Checks the status of the environment variables
+ *
+ * At this moment it only checks NO_AT_BRIDGE
+ *
+ * Returns TRUE if there isn't anything on the environment preventing
+ * you to load the bridge, FALSE otherwise
+ */
+static gboolean
+check_envvar (void)
+{
+  const gchar *envvar;
+
+  envvar = g_getenv ("NO_AT_BRIDGE");
+
+  if (envvar && atoi (envvar) == 1)
+    return FALSE;
+  else
+    return TRUE;
+}
+
 /*
  * spi_app_init
  *
@@ -772,23 +748,25 @@ signal_filter (DBusConnection *bus, DBusMessage *message, void *user_data)
  * - Application registration with the AT-SPI registry.
  *
  */
-static int
-adaptor_init (gint * argc, gchar ** argv[])
+int
+atk_bridge_adaptor_init (gint * argc, gchar ** argv[])
 {
   GOptionContext *opt;
   GError *err = NULL;
   DBusError error;
   AtkObject *root;
-  gchar *introspection_directory;
-  static gboolean inited = FALSE;
+  gboolean load_bridge;
+  DRoutePath *treepath, *accpath;
 
-  if (inited)
+  load_bridge = check_envvar ();
+  if (inited && !load_bridge)
+    g_warning ("ATK Bridge is disabled but a11y has already been enabled.");
+
+  if (inited || !load_bridge)
     return 0;
 
   inited = TRUE;
 
-  DRoutePath *treepath, *accpath;
-
   root = atk_get_root ();
   g_warn_if_fail (root);
   if (!root)
@@ -895,7 +873,8 @@ adaptor_init (gint * argc, gchar ** argv[])
                            spi_global_app_data->bus);
 
   /* Register methods to send D-Bus signals on certain ATK events */
-  spi_atk_register_event_listeners ();
+  if (clients)
+    spi_atk_register_event_listeners ();
 
   /* Set up filter and match rules to catch signals */
   dbus_bus_add_match (spi_global_app_data->bus, "type='signal', interface='org.a11y.atspi.Registry', sender='org.a11y.atspi.Registry'", NULL);
@@ -914,50 +893,14 @@ adaptor_init (gint * argc, gchar ** argv[])
   return 0;
 }
 
-/*---------------------------------------------------------------------------*/
-
-int
-gtk_module_init (gint * argc, gchar ** argv[])
-{
-  const gchar *load_bridge = g_getenv ("NO_AT_BRIDGE");
-
-  if (!load_bridge || g_ascii_strtod (load_bridge, NULL) == 0)
-    {
-      return adaptor_init (argc, argv);
-    }
-  return 0;
-}
-
-gchar*
-g_module_check_init (GModule *module)
-{
-  g_module_make_resident (module);
-
-  return NULL;
-}
-
 void
-gnome_accessibility_module_init (void)
-{
-  const gchar *load_bridge = g_getenv ("NO_AT_BRIDGE");
-
-  if (!load_bridge || g_ascii_strtod (load_bridge, NULL) == 0)
-    {
-      adaptor_init (NULL, NULL);
-
-      if (g_getenv ("AT_SPI_DEBUG"))
-        {
-          g_print ("Atk Accessibility bridge initialized\n");
-        }
-    }
-}
-
-void
-gnome_accessibility_module_shutdown (void)
+atk_bridge_adaptor_cleanup (void)
 {
   GList *l;
   GSList *ls;
 
+  g_return_if_fail (inited);
+
   if (!spi_global_app_data)
       return;
 
@@ -1002,13 +945,11 @@ gnome_accessibility_module_shutdown (void)
   g_free (spi_global_app_data);
   spi_global_app_data = NULL;
 
-  /* Not currently creating an XDisplay */
-#if 0
-  if (bridge_display)
-    XCloseDisplay (bridge_display);
-#endif
+  inited = FALSE;
 }
 
+/*---------------------------------------------------------------------------*/
+
 static gchar *name_match_tmpl =
        "type='signal', interface='org.freedesktop.DBus', member='NameOwnerChanged', arg0='%s'";
 
@@ -1023,7 +964,7 @@ spi_atk_add_client (const char *bus_name)
     if (!g_strcmp0 (l->data, bus_name))
       return;
   }
-  if (!clients && spi_global_app_data->events_initialized)
+  if (!clients)
     spi_atk_register_event_listeners ();
   clients = g_slist_append (clients, g_strdup (bus_name));
   match = g_strdup_printf (name_match_tmpl, bus_name);
